@@ -168,6 +168,10 @@ class VirtualServiceMissingLoadmasterInfo(MissingInfo):
     service = 'Virtual service'
     param_name = 'LoadMaster'
 
+class LDAPMissingLoadMasterInfo(MissingInfo):
+    service = 'LDAP'
+    param_name = 'LoadMaster'
+
 
 class RealServerMissingLoadmasterInfo(MissingInfo):
     service = 'Real server'
