@@ -22,7 +22,8 @@ from python_kemptech_api.exceptions import (
     CommandNotAvailableException,
     UserAlreadyExistsException,
     DownloadUserCertFailed,
-    NotVirtualServiceInstanceError
+    NotVirtualServiceInstanceError,
+    LDAPMissingLoadMasterInfo
 )
 from python_kemptech_api.generic import HttpClient, AccessInfoMixin
 from python_kemptech_api.objects import (
@@ -40,7 +41,8 @@ from python_kemptech_api.objects import (
     Interface,
     IntermediateCertificate,
     License,
-    Subscription)
+    Subscription,
+    LDAP)
 from python_kemptech_api.utils import (
     send_response,
     validate_port,
@@ -1406,6 +1408,18 @@ class LoadMaster(BaseKempAppliance):
     def create_virtual_service(self, ip, port=80, protocol="tcp"):
         return VirtualService(self.access_info, ip, port, protocol)
 
+    def create_ldap(self, ldap_obj):
+        return LDAP(self.access_info, ldap_obj)
+
+    def get_ldap_endpoint(self, ldap_obj=None):
+        if ldap_obj:
+            response = self._get("/showldapendpoint", {'name': ldap_obj['name']})
+        else:
+            response = self._get("/showldaplist")
+        if is_successful(response):
+            ldap_data = get_data(response)
+            return ldap_data
+
     def get_virtual_services(self):
         response = self._get("/listvs")
         data = get_data(response)
@@ -1659,5 +1673,7 @@ class LoadMaster(BaseKempAppliance):
         return send_response(response)
 
 
+
+
 class LoadMasterGeo(LoadMaster, Geo):
     pass
